#include <string>

#include "crow.h"
#include <pqxx/pqxx>

#include "dotenv.hpp"
#include "json.hpp"

pqxx::connection* globalConnection(nullptr);
crow::response test(void);
Etheryo::JsonHandler category;

int main()
{
    // Init Json Objects
    category.add({ "id", "slug", "icon", "type_icon" });

    // Init Postgresql + DotEnv
    Etheryo::DotEnv dotenvParser;
    dotenvParser.readFile("res/.env");
    globalConnection = new pqxx::connection(dotenvParser["DATABASE_URL"]);
    std::cout << "Connected to " << globalConnection->dbname() << '\n';

    // Init Crow App
    crow::SimpleApp app;
    CROW_ROUTE(app, "/")
    (test);

    app.port(8000).multithreaded().run();
    globalConnection->close();
}

crow::response test(void)
{
    category.clear();
    pqxx::work worker { *globalConnection };
    auto result = worker.query<int, std::string, std::string, std::string>("select c.id, c.slug, c.icon, c.type_icon FROM category c ORDER BY c.id;");
    for (auto [id, slug, icon, type_icon] : result) {
        category["id"] = std::to_string(id);
        category["slug"] = slug;
        category["icon"] = icon;
        category["type_icon"] = type_icon;
        category.push();
    }
    auto response = crow::response { "application/json", category.to_str() };
    response.add_header("Access-Control-Allow-Origin", "*");
    response.add_header("Access-Control-Allow-Headers", "Origin, X-Requested-With, Content-Type, Accept");
    return response;
}